==> haskell-tls-session-manager-0.0.0.2-79-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tls-session-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tls-session-manager
version: 0.0.0.2
id: tls-session-manager-0.0.0.2-AWcmuZwydLtF2MD7tzFnhk
key: tls-session-manager-0.0.0.2-AWcmuZwydLtF2MD7tzFnhk
license: BSD-3-Clause
maintainer: kazu@iij.ad.jp
author: Kazu Yamamoto
synopsis: In-memory TLS session manager
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance
category: Web
abi: 8b2dd2baaafb0f0ceeed4ecc3aa9218d
exposed: True
exposed-modules:
    Network.TLS.SessionManager
hidden-modules: Network.TLS.Imports
import-dirs: /usr/lib/ghc-8.6.2/site-local/tls-session-manager-0.0.0.2
library-dirs: /usr/lib/ghc-8.6.2/site-local/tls-session-manager-0.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/tls-session-manager-0.0.0.2
hs-libraries: HStls-session-manager-0.0.0.2-AWcmuZwydLtF2MD7tzFnhk
depends:
    auto-update-0.1.4-JkSw4eg9S3X18mq8pcespF base-4.12.0.0
    clock-0.7.2-DpdvDKMysiO5fhuByT1Vyj
    psqueues-0.2.7.0-KUVejJ6deoBOKGhMhIlo7
    tls-1.4.1-H27kxR6HkdZAt3SyqV3SrH
haddock-interfaces: /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock
haddock-html: /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tls-session-manager-0.0.0.2-82-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tls-session-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tls-session-manager
version: 0.0.0.2
id: tls-session-manager-0.0.0.2-DXiQ2CzUHRLBhJdysV4VJl
key: tls-session-manager-0.0.0.2-DXiQ2CzUHRLBhJdysV4VJl
license: BSD-3-Clause
maintainer: kazu@iij.ad.jp
author: Kazu Yamamoto
synopsis: In-memory TLS session manager
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance
category: Web
abi: 8a7764d71f813879dbe32eed251dfb48
exposed: True
exposed-modules:
    Network.TLS.SessionManager
hidden-modules: Network.TLS.Imports
import-dirs: /usr/lib/ghc-8.6.3/site-local/tls-session-manager-0.0.0.2
library-dirs: /usr/lib/ghc-8.6.3/site-local/tls-session-manager-0.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/tls-session-manager-0.0.0.2
hs-libraries: HStls-session-manager-0.0.0.2-DXiQ2CzUHRLBhJdysV4VJl
depends:
    auto-update-0.1.4-JkSw4eg9S3X18mq8pcespF base-4.12.0.0
    clock-0.7.2-DpdvDKMysiO5fhuByT1Vyj
    psqueues-0.2.7.1-FQACYBUlHP5D61ftFqHex
    tls-1.4.1-L64TVhVlBfp7wZ6gAajWFQ
haddock-interfaces: /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock
haddock-html: /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
